@@ -117,7 +117,7 @@ def get_instance_info(instances, class_instance):
         try:
             instance_tags = instance['Instances'][0]['Tags']
         except KeyError as e:
-            instance_tags = ""
+            instance_tags = []
         tags_list = ""
         for instance_tag in instance_tags:
             # call a function to check tags and hints
@@ -126,6 +126,14 @@ def get_instance_info(instances, class_instance):
                 matching_hints += 1
             tags_list += instance_tag['Key']+":"+instance_tag['Value']+", "
         tags_list = tags_list[:-2]
+        try:
+            instance_sgs = instance_tags = instance['Instances'][0]['SecurityGroups']
+        except KeyError as e:
+            instance_sgs = []
+        sgs_list = ""
+        for sg in instance_sgs:
+            sgs_list += sg['GroupName']+", "
+        sgs_list = sgs_list[:-2]
         if state_code == 16:
             state_color = "green"
             instance_ip = instance['Instances'][0]['PublicIpAddress']
@@ -155,10 +163,10 @@ def get_instance_info(instances, class_instance):
         else:
             if class_instance.hint:
                 if matching_hint:
-                    print(cs(state_name+"\n"+description+"\nKey Name: "+instance_key_name+"\nTags: "+tags_list, state_color))
+                    print(cs(state_name+"\n"+description+"\nKey Name: "+instance_key_name+"\nSecurity Groups: "+sgs_list+"\nTags: "+tags_list, state_color))
                     print("-------")
             else:
-                print(cs(state_name+"\n"+description+"\nKey Name: "+instance_key_name+"\nTags: "+tags_list, state_color))
+                print(cs(state_name+"\n"+description+"\nKey Name: "+instance_key_name+"\nSecurity Groups: "+sgs_list+"\nTags: "+tags_list, state_color))
                 print("-------")
     if class_instance.hint:
         if matching_hints < 1:
